@@ -21,8 +21,6 @@ def run(dataset_splited, batch_size, K, num_nodes, model, objective, optimizer,
     server = server_class(device)
     server.assign_model(model())
     server.model_g = deepcopy(model_g)
-    # print(server.model_g.state_dict()['fc.bias'])
-    print(len(DataLoader(train_splited[0], batch_size=batch_size, shuffle=True)), len(DataLoader(train_splited[0], batch_size=batch_size, shuffle=True).dataset))
 
     nodes = [node(i, device) for i in range(num_nodes)]
 
@@ -48,8 +46,10 @@ def run(dataset_splited, batch_size, K, num_nodes, model, objective, optimizer,
         for i in range(num_nodes):
             m = 0
             for k in range(1, K):
-                # print(nodes[i].local_train_loss(cluster_models[m]), nodes[i].local_train_loss(cluster_models[k]))
-                if nodes[i].local_train_loss(cluster_models[m])>=nodes[i].local_train_loss(cluster_models[k]):
+                # if i <=5:
+                #     print(nodes[i].local_train_acc(cluster_models[m]), nodes[i].local_train_acc(cluster_models[k]))
+                # if nodes[i].local_train_loss(cluster_models[m])>=nodes[i].local_train_loss(cluster_models[k]):
+                if nodes[i].local_train_acc(cluster_models[m])<=nodes[i].local_train_acc(cluster_models[k]):
                     m = k
             assignment[m].append(i)
             nodes[i].assign_model(cluster_models[m])
@@ -63,28 +63,29 @@ def run(dataset_splited, batch_size, K, num_nodes, model, objective, optimizer,
         print([len(assignment[i]) for i in range(len(assignment))])
 
         # local update
+        # for j in range(num_nodes):
+        #     nodes[j].local_update_steps(local_steps, partial(nodes[j].train_single_step_res, optimizer = nodes[j].optim['local'], \
+        #         model_opt = nodes[j].model, model_fix = nodes[j].model_g))
+        
         for j in range(num_nodes):
-            nodes[j].local_update_steps(local_steps, partial(nodes[j].train_single_step_res, optimizer = nodes[j].optim['local'], \
+            nodes[j].local_update_steps(local_steps, partial(nodes[j].train_single_step_res, optimizer = nodes[j].optim['all'], \
                 model_opt = nodes[j].model, model_fix = nodes[j].model_g))
-            nodes[j].local_update_steps(local_steps, partial(nodes[j].train_single_step_res, optimizer = nodes[j].optim['global'],\
-                model_opt = nodes[j].model_g, model_fix = nodes[j].model))
-            
+
         # server aggregation and distribution by cluster
         for k in range(K):
             if len(assignment[k])>0:
                 server.aggregate(nodes, assignment[k])
                 server.distribute(nodes, assignment[k])
                 cluster_models[k].load_state_dict(server.model.state_dict())
-
+        
+        # for j in range(num_nodes):
+        #     nodes[j].local_update_steps(local_steps, partial(nodes[j].train_single_step_res, optimizer = nodes[j].optim['global'],\
+        #         model_opt = nodes[j].model_g, model_fix = cluster_models[[l for l in range(K) if j in assignment[l]][0]]))
+            
         # aggregate model_g
         server.aggregate_model_g(nodes, list(range(num_nodes)))
         server.distribute_model_g(nodes, list(range(num_nodes)))
 
-        # print(nodes[0].model.state_dict()['fc.bias'])
-        # print(nodes[0].model_g.state_dict()['fc.bias'])
-        # print(nodes[1].model.state_dict()['fc.bias'])
-        # print(nodes[1].model_g.state_dict()['fc.bias'])
-
         # test accuracy
         for i in range(num_nodes):
             nodes[i].local_test()
