@@ -47,7 +47,7 @@ def run(dataset_splited, batch_size, K, num_nodes, model, objective, optimizer,
     cluster_models = [model() for i in range(K)]
 
     # initialize clustering and distribute
-    server.weighted_clu.stering(nodes, list(range(num_nodes)), K)
+    server.weighted_clustering(nodes, list(range(num_nodes)), K)
     for i in range(K):
         server.aggregate(nodes, [j for j in list(range(num_nodes)) if nodes[j].label==i])
         server.distribute(nodes, [j for j in list(range(num_nodes)) if nodes[j].label==i])
@@ -57,12 +57,16 @@ def run(dataset_splited, batch_size, K, num_nodes, model, objective, optimizer,
     for i in range(global_rounds - warmup_rounds):
         print('-------------------Global round %d start-------------------' % (i))
         # local update
+        # for j in range(num_nodes):
+        #     nodes[j].local_update_steps(local_steps, partial(nodes[j].train_single_step_res, optimizer = nodes[j].optim['global'],\
+        #         model_opt = nodes[j].model_g, model_fix = cluster_models[[l for l in range(K) if j in assignment[l]][0]]))
+        #     nodes[j].local_update_steps(local_steps, partial(nodes[j].train_single_step_res, optimizer = nodes[j].optim['local'], \
+        #         model_opt = nodes[j].model, model_fix = nodes[j].model_g))
+
         for j in range(num_nodes):
-            nodes[j].local_update_steps(local_steps, partial(nodes[j].train_single_step_res, optimizer = nodes[j].optim['global'],\
-                model_opt = nodes[j].model_g, model_fix = nodes[j].model))
-            nodes[j].local_update_steps(local_steps, partial(nodes[j].train_single_step_res, optimizer = nodes[j].optim['local'], \
+            nodes[j].local_update_steps(local_steps, partial(nodes[j].train_single_step_res, optimizer = nodes[j].optim['all'], \
                 model_opt = nodes[j].model, model_fix = nodes[j].model_g))
-            
+
         # server clustering
         server.weighted_clustering(nodes, list(range(num_nodes)), K)
 
